==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Gambar</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation type="unfinished">Info gambar</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>File ini berisi beberapa halaman, silakan gunakan Evince untuk melihat semua halaman.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation type="vanished">Buka Direktori</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Anda tidak punya hak akses untuk melihat gambar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Hapus</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Tanggal dimodifikasi</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="vanished">Dimensi</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Ukuran gambar</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode eksposur</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program eksposur</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Waktu eksposur</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Aperture</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Jarak fokus</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertur maksimal</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode pengukuran</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Keseimbangan putih</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flash compensation</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model lensa</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Ruang warna</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamera</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Tidak ada penskalaan</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Sesuaikan halaman dengan gambar</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Sesuaikan gambar dengan halaman</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skala untuk:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Sentimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inci</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posisi Gambar</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Penskalaan</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Pengaturan Gambar</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="vanished">Pengaturan Gambar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation type="vanished">Tirai</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation type="vanished">Switcher</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Pilih Direktori</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Direktori ini dinon-aktifkan untuk sinkronisasi</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Tambah folder</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Manajemen sinkronisasi direktori</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Daftar direktori kosong</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Batalkan sinkronisasi</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Perangkat telah dilepaskan</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Direktori ini sudah tidak tersedia</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Menghitung...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Melihat Gambar</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Akhiri tampilan</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hapus dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batalkan favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info gambar</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Sebelumnya</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Selanjutnya</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Layar sebelumnya</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Layar sleanjutnya</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baru</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ganti nama</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tampilkan pintasan</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Keluar layar penuh</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation type="vanished">Silakan masukkan pintasan baru</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">Pintasan</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation type="vanished">Lihat gambar</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation type="vanished">Kembalikan Bawaan</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation type="vanished">Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Layar penuh</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="vanished">Akhiri tampilan</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="vanished">Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="vanished">Hapus dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="vanished">Batalkan favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="vanished">Info gambar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="vanished">Album baru</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">Ganti nama</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Hapus</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Sebelumnya</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Selanjutnya</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Duration</source>
        <translation type="vanished">Durasi</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation type="vanished">Tukar durasi</translation>
    </message>
    <message>
        <source>second</source>
        <translation type="vanished">detik</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation type="unfinished">Favorit saya</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Sebelumnya</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Selanjutnya</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Hapus</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Kembali</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Manajemen gambar</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorit saya</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished">Batalkan favorit</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">Favorit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Tidak ada berkas gambar ditemukan</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Buka Gambar</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Effect</source>
        <translation type="vanished">Efek</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="vanished">Durasi</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="vanished">Pintasan</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="vanished">Lihat</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="vanished">Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation type="vanished">Album baru</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Pengaturan</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Linimasa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambahkan ke albu</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tambahkan ke album baru</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Keluar layar penuh</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hapus dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Batalkan favorit</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Tampilkan jendela navigasi</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Sembunyikan jendela navigasi</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info gambar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Hapus</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished">Buka Gambar</translation>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ganti nama</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.6.orig.tar.xz: deepin-image-viewer-5.9.6/src/translations/deepin-image-viewer_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Buka Gambar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Melihat Gambar</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Keluar layar penuh</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation></translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Ganti nama</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar arah jarum jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar kebalikan arah jarum jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Setel sebagai wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tampilkan dalam manajer berkas</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info gambar</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Sebelumnya</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Selanjutnya</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation></translation>
    </message>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tampilkan pintasan</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation></translation>
    </message>
</context>
</TS>
